@@ -216,3 +216,113 @@ expr_corr_test <- function(data,
   # return the subtitle
   return(subtitle)
 }
+
+
+#' @name corr_objects
+#' @title Create all needed objects for correlation matrix.
+#' @description This function is mostly useful in the context of
+#'   `ggstatsplot::ggcorrmat`. It returns the correlation matrix, *p*-value
+#'   matrix, and a correlation object from `psych`/`WRS2` package that contains
+#'   all the details about the test.
+#'
+#' @note This is **not** a stable function and would likely to either change or
+#'   completely go away in future. So avoid using it in your workflows.
+#'
+#' @return A list with all needed objects for displaying correlation tests in a
+#'   correlation matrix visualization.
+#'
+#' @param ... Currently ignored.
+#' @param data Dataframe from which variables specified are preferentially to be
+#'   taken. Only numeric variables should be present.
+#' @param corr.method A character string indicating which correlation
+#'   coefficient is to be computed (`"pearson"` (default) or `"kendall"` or
+#'   `"spearman"`). `"robust"` can also be entered but only if `output` argument
+#'   is set to either `"correlations"` or `"p-values"`. The robust correlation
+#'   used is percentage bend correlation (see `?WRS2::pball`). Abbreviations
+#'   will also work: `"p"` (for parametric/Pearson's *r*), `"np"`
+#'   (nonparametric/Spearman's *rho*), `"r"` (robust).
+#' @param p.adjust.method What adjustment for multiple tests should be used?
+#'   (`"holm"`, `"hochberg"`, `"hommel"`, `"bonferroni"`, `"BH"`, `"BY"`,
+#'   `"fdr"`, `"none"`). See `stats::p.adjust` for details about why to use
+#'   `"holm"` rather than `"bonferroni"`). Default is `"none"`. If adjusted
+#'   *p*-values are displayed in the visualization of correlation matrix, the
+#'   **adjusted** *p*-values will be used for the **upper** triangle, while
+#'   **unadjusted** *p*-values will be used for the **lower** triangle of the
+#'   matrix.
+#' @param beta A numeric bending constant for percentage bend robust correlation
+#'   coefficient (Default: `0.1`).
+#' @param k Decides the number of decimal digits to be displayed
+#'   (Default: `2`).
+#' @inheritParams psych::corr.test
+#'
+#' @examples
+#' # only numeric variables
+#' df <- purrr::keep(WRS2::diet, purrr::is_bare_numeric)
+#'
+#' # using function
+#' corr_objects(df)
+#' @export
+
+corr_objects <- function(data,
+                         ci = FALSE,
+                         corr.method = "pearson",
+                         p.adjust.method = "none",
+                         beta = 0.1,
+                         k = 2,
+                         ...) {
+  if (corr.method %in% c("pearson", "spearman")) {
+    # computing correlations using `psych` package
+    psych_corr_obj <-
+      psych::corr.test(
+        x = as.data.frame(data),
+        use = "pairwise",
+        method = corr.method,
+        adjust = p.adjust.method,
+        alpha = 0.05,
+        ci = ci,
+        minlength = 20
+      )
+
+    # computing correlations on all included variables
+    corr.mat <- round(x = psych_corr_obj$r, digits = k)
+
+    # compute a correlation matrix of p-values
+    p.mat <- psych_corr_obj$p
+  }
+
+  # robust correlation
+  if (corr.method == "robust") {
+    # get matrix of samples sizes to be used later in `corr.p` function (`n`)
+    psych_corr_obj <-
+      psych::corr.test(
+        x = as.data.frame(data),
+        use = "pairwise",
+        adjust = "none",
+        alpha = 0.05,
+        ci = FALSE,
+        minlength = 20
+      )
+
+    # computing the percentage bend correlation matrix
+    rob_cor <- WRS2::pball(x = data, beta = beta)
+
+    # extracting the correlations and formatting them
+    corr.mat <- round(x = rob_cor$pbcorm, digits = k)
+
+    # converting `NA`s to 0's
+    rob_cor$p.values[is.na(rob_cor$p.values)] <- 0
+
+    # adjusting for multiple comparisons (if needed)
+    p.mat <-
+      psych::corr.p(
+        r = corr.mat,
+        n = psych_corr_obj$n,
+        adjust = p.adjust.method,
+        alpha = 0.05,
+        minlength = 20
+      )$p
+  }
+
+  # return everything as a list
+  list("corr.mat" = corr.mat, "p.mat" = p.mat, "psych_corr_obj" = psych_corr_obj)
+}
