@@ -43,7 +43,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("d"),
+          widehat(italic("d")),
           " = ",
           "-0.92473",
           ", CI"["99%"],
@@ -107,7 +107,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("g"),
+          widehat(italic("g")),
           " = ",
           "-0.863",
           ", CI"["90%"],
@@ -166,7 +166,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("g"),
+          widehat(italic("g")),
           " = ",
           "2.8282",
           ", CI"["50%"],
@@ -223,7 +223,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("d"),
+          widehat(italic("d")),
           " = ",
           "0.381",
           ", CI"["95%"],
